# ApertureDB Client Python Module

This is the python client module for ApertureDB.

It provides a connector to AperetureDB instances using
the open source connector for [VDMS](https://github.com/IntelLabs/vdms).

It also implements an Object-Mapper API to interact with
elements in ApertureDB at the object level.

* Status.py provides helper methods to retrieve information about the db.
* Images.py provides the Object-Mapper for image related objetcs (images, bounding boxes, etc)
* NotebookHelpers.py provides helpers to show images/bounding boxes on Jupyter Notebooks

For more information, visit https://aperturedata.io
